summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2021-09-29 12:56:32 +0100
committerCaolán McNamara <caolanm@redhat.com>2021-09-29 15:02:11 +0200
commite9564f1d727e89e8ab7c441a80a3944de10b3d3d (patch)
tree92d0ff8d54a434f84584a481c2597695c4fc5d2a /svx
parent99983c3c0b855a3449cf974224fae338b578dbd5 (diff)
Resolves: tdf#144783 shift+RETURN not searching backwards
In gtk nothing is happening, in gen its searching forwards. Align backends so that Activate is emitted only on a bare return in both and then handle shift+RETURN explicitly for the search widget Change-Id: I142002bbaf6b3aca83800a442096a4b1024fe097 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/122814 Tested-by: Jenkins Reviewed-by: Caolán McNamara <caolanm@redhat.com>
Diffstat (limited to 'svx')
-rw-r--r--svx/source/tbxctrls/tbunosearchcontrollers.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/svx/source/tbxctrls/tbunosearchcontrollers.cxx b/svx/source/tbxctrls/tbunosearchcontrollers.cxx
index 786c95698c05..d315e79f9b3b 100644
--- a/svx/source/tbxctrls/tbunosearchcontrollers.cxx
+++ b/svx/source/tbxctrls/tbunosearchcontrollers.cxx
@@ -297,8 +297,8 @@ IMPL_LINK(FindTextFieldControl, KeyInputHdl, const KeyEvent&, rKeyEvent, bool)
else if ( bMod1 && nCode == KEY_F )
m_xWidget->select_entry_region(0, -1);
- // Execute the search when Ctrl-G or F3 pressed (in addition to ActivateHdl conditions)
- else if ( (bMod1 && (KEY_G == nCode)) || (KEY_F3 == nCode) )
+ // Execute the search when Ctrl-G, F3 and Shift-RETURN pressed (in addition to ActivateHdl condition which handles bare RETURN)
+ else if ( (bMod1 && KEY_G == nCode) || (bShift && KEY_RETURN == nCode) || (KEY_F3 == nCode) )
{
ActivateFind(bShift);
bRet = true;